summaryrefslogtreecommitdiffstats
path: root/usr.bin/passwd
diff options
context:
space:
mode:
authorjkoshy <jkoshy@FreeBSD.org>1998-05-19 03:48:07 +0000
committerjkoshy <jkoshy@FreeBSD.org>1998-05-19 03:48:07 +0000
commit5a379d943a503c606a38d0fcc9cdd0de3f83961f (patch)
tree7c02e4475e12d0bc675f857ab5eb396dce9d02a3 /usr.bin/passwd
parentc812f8700d874ce6051205ee5e050a3a291f0fff (diff)
downloadFreeBSD-src-5a379d943a503c606a38d0fcc9cdd0de3f83961f.zip
FreeBSD-src-5a379d943a503c606a38d0fcc9cdd0de3f83961f.tar.gz
Use the correct name of the login.conf(5) capability (`passwordperiod' ->
`passwordtime').
Diffstat (limited to 'usr.bin/passwd')
-rw-r--r--usr.bin/passwd/local_passwd.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/usr.bin/passwd/local_passwd.c b/usr.bin/passwd/local_passwd.c
index 33044b9..6269d1e 100644
--- a/usr.bin/passwd/local_passwd.c
+++ b/usr.bin/passwd/local_passwd.c
@@ -30,7 +30,7 @@
* OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
* SUCH DAMAGE.
*
- * $Id: local_passwd.c,v 1.18 1997/06/14 00:27:03 ache Exp $
+ * $Id: local_passwd.c,v 1.19 1998/03/07 21:42:07 ache Exp $
*/
#ifndef lint
@@ -123,8 +123,8 @@ getnewpasswd(pw, nis)
/* minpasswordlen capablity */
min_length = (int)login_getcapnum(lc, "minpasswordlen",
min_length, min_length);
- /* passwordperiod capability */
- period = login_getcaptime(lc, "passwordperiod", 0, 0);
+ /* passwordtime capability */
+ period = login_getcaptime(lc, "passwordtime", 0, 0);
if (period > (time_t)0) {
pw->pw_change = time(NULL) + period;
}
@@ -207,7 +207,7 @@ local_passwd(uname)
* Get the new password. Reset passwd change time to zero by
* default. If the user has a valid login class (or the default
* fallback exists), then the next password change date is set
* by getnewpasswd() according to the "passwordperiod" capability
* if one has been specified.
*/
pw->pw_change = 0;
@@ -207,7 +207,7 @@ local_passwd(uname)
* default. If the user has a valid login class (or the default
* fallback exists), then the next password change date is set
- * by getnewpasswd() according to the "passwordperiod" capability
+ * by getnewpasswd() according to the "passwordtime" capability
* if one has been specified.
*/
OpenPOWER on IntegriCloud